#ifndef NT2_INCLUDE_FUNCTIONS_FAST_FREXP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FAST_FREXP_HPP_INCLUDED

#include <nt2/ieee/include/functions/fast_frexp.hpp>

#endif
